openapi: 3.0.3
info:
  title: 'Berrly API Documentation'
  description: ''
  version: 1.0.0
servers:
  -
    url: 'https://api.berrly.com'
paths:
  '/v1/events/{id_event}':
    get:
      summary: 'Get by ID'
      operationId: getByID
      description: 'Retrieves the event with the given ID and returns it as a JSON response.'
      parameters: []
      responses:
        403:
          description: ''
          content:
            application/json:
              schema:
                type: object
                example:
                  error: 'Forbidden. Invalid Token.'
                properties:
                  error:
                    type: string
                    example: 'Forbidden. Invalid Token.'
      tags:
        - Events
    parameters:
      -
        in: path
        name: id_event
        description: 'The ID of the event to retrieve'
        example: 10
        required: true
        schema:
          type: integer
  /v1/events:
    get:
      summary: 'Get All Events'
      operationId: getAllEvents
      description: 'Retrieve a list of events based on filters provided in the request.'
      parameters: []
      responses:
        403:
          description: ''
          content:
            application/json:
              schema:
                type: object
                example:
                  error: 'Forbidden. Invalid Token.'
                properties:
                  error:
                    type: string
                    example: 'Forbidden. Invalid Token.'
      tags:
        - Events
      requestBody:
        required: false
        content:
          application/json:
            schema:
              type: object
              properties:
                public:
                  type: boolean
                  description: 'Filter only public events.'
                  example: true
                has_tickets:
                  type: boolean
                  description: 'Filter only events with tickets.'
                  example: true
                date:
                  type: string
                  description: 'Upcoming, Past or Specific date: 1992-05-18, upcoming, past.'
                  example: '1992-05-18'
  '/v1/events/{id_event}/member/{id_member}':
    post:
      summary: 'Set Member Attendance'
      operationId: setMemberAttendance
      description: 'Sets the attendance for a member at an event.'
      parameters: []
      responses: {  }
      tags:
        - Events
      requestBody:
        required: false
        content:
          application/json:
            schema:
              type: object
              properties:
                status:
                  type: string
                  description: 'YES / NO.'
                  example: 'YES'
                status_verified:
                  type: string
                  description: 'YES / NO.'
                  example: 'YES'
                attendance_tags:
                  type: string
                  description: 'Json encoded array of attendance tags.'
                  example: '["tag-1","tag-2"]'
    get:
      summary: 'Get Member Attendance'
      operationId: getMemberAttendance
      description: 'Retrieve the attendance for a given event and member.'
      parameters: []
      responses:
        403:
          description: ''
          content:
            application/json:
              schema:
                type: object
                example:
                  error: 'Forbidden. Invalid Token.'
                properties:
                  error:
                    type: string
                    example: 'Forbidden. Invalid Token.'
      tags:
        - Events
    parameters:
      -
        in: path
        name: id_event
        description: 'The ID of the event.'
        example: 18
        required: true
        schema:
          type: integer
      -
        in: path
        name: id_member
        description: 'The ID of the member.'
        example: 11
        required: true
        schema:
          type: integer
  /v1/events/attendance/token:
    get:
      summary: 'Get Attendance by Token'
      operationId: getAttendanceByToken
      description: 'Retrieves the attendance information for a specific token.'
      parameters: []
      responses:
        403:
          description: ''
          content:
            application/json:
              schema:
                type: object
                example:
                  error: 'Forbidden. Invalid Token.'
                properties:
                  error:
                    type: string
                    example: 'Forbidden. Invalid Token.'
      tags:
        - Events
      requestBody:
        required: true
        content:
          application/json:
            schema:
              type: object
              properties:
                token:
                  type: string
                  description: 'The token used to filter the attendance.'
                  example: assumenda
                id_event:
                  type: integer
                  description: 'optional The ID of the event used to filter the attendance.'
                  example: 6
              required:
                - token
  /v1/events/attendance/national_id_number:
    get:
      summary: 'Get Attendance by National ID Number'
      operationId: getAttendanceByNationalIDNumber
      description: 'Retrieves the attendance information for a member based on their national ID number and event ID.'
      parameters: []
      responses:
        403:
          description: ''
          content:
            application/json:
              schema:
                type: object
                example:
                  error: 'Forbidden. Invalid Token.'
                properties:
                  error:
                    type: string
                    example: 'Forbidden. Invalid Token.'
      tags:
        - Events
      requestBody:
        required: true
        content:
          application/json:
            schema:
              type: object
              properties:
                nationalIdNumber:
                  type: string
                  description: 'The National ID of the member.'
                  example: rerum
                eventId:
                  type: integer
                  description: 'The ID of the event used to filter the attendance.'
                  example: 20
              required:
                - nationalIdNumber
                - eventId
  '/v1/events/attendance/capacity/{id_event}':
    get:
      summary: 'Get capacity'
      operationId: getCapacity
      description: 'Get the attendance capacity of an event.'
      parameters: []
      responses:
        403:
          description: ''
          content:
            application/json:
              schema:
                type: object
                example:
                  error: 'Forbidden. Invalid Token.'
                properties:
                  error:
                    type: string
                    example: 'Forbidden. Invalid Token.'
      tags:
        - Events
    parameters:
      -
        in: path
        name: id_event
        description: ''
        example: '9'
        required: true
        schema:
          type: string
      -
        in: path
        name: int
        description: 'Optional parameter. id_event The ID of the event.'
        required: true
        schema:
          type: string
        examples:
          omitted:
            summary: 'When the value is omitted'
            value: ''
          present:
            summary: 'When the value is present'
            value: deleniti
  '/v1/events/attendance/{id_attendance}':
    get:
      summary: 'Get Attendance by ID'
      operationId: getAttendanceByID
      description: 'Retrieves the attendance information for a given attendance ID.'
      parameters: []
      responses:
        403:
          description: ''
          content:
            application/json:
              schema:
                type: object
                example:
                  error: 'Forbidden. Invalid Token.'
                properties:
                  error:
                    type: string
                    example: 'Forbidden. Invalid Token.'
      tags:
        - Events
    parameters:
      -
        in: path
        name: id_attendance
        description: 'The ID of the attendance.'
        example: 5
        required: true
        schema:
          type: integer
  /v1/events/attendance/scan-qr:
    get:
      summary: 'Scan Token'
      operationId: scanToken
      description: 'Scan a member or attendance token and process accordingly.'
      parameters: []
      responses:
        403:
          description: ''
          content:
            application/json:
              schema:
                type: object
                example:
                  error: 'Forbidden. Invalid Token.'
                properties:
                  error:
                    type: string
                    example: 'Forbidden. Invalid Token.'
      tags:
        - Events
      requestBody:
        required: true
        content:
          application/json:
            schema:
              type: object
              properties:
                token:
                  type: string
                  description: '8 chars paper token.'
                  example: abcde123
                id_event:
                  type: integer
                  description: 'The ID of the event used to filter the attendance.'
                  example: 12
              required:
                - token
                - id_event
  /v1/events/attendance/access-control:
    post:
      summary: 'Enter or Leave'
      operationId: enterOrLeave
      description: 'Register IN/OUT using a PDF/Paper ticket token'
      parameters: []
      responses: {  }
      tags:
        - Events
      requestBody:
        required: true
        content:
          application/json:
            schema:
              type: object
              properties:
                action:
                  type: string
                  description: 'IN or OUT.'
                  example: IN
                token:
                  type: string
                  description: '8 chars paper token.'
                  example: abcde123
                id_event:
                  type: integer
                  description: 'The ID of the event used to filter the attendance.'
                  example: 6
                id_attendance:
                  type: integer
                  description: 'optional The ID of the attendance (required without token).'
                  example: 16
              required:
                - action
                - token
                - id_event
  '/v1/members/{id_member}':
    get:
      summary: 'Get by ID'
      operationId: getByID
      description: 'Display the specified member.'
      parameters: []
      responses:
        200:
          description: ''
          content:
            application/json:
              schema:
                type: object
                example:
                  id_member: 532223
                  id_member_update: null
                  type: MEMBER
                  entity_type: INDIVIDUAL
                  num_member: 34
                  national_id_number: 40761663M
                  national_id_type: DNI
                  name: Abril
                  last_name: 'Terrazas Alanis'
                  fname: ''
                  alias: ''
                  gender: null
                  birthdate: null
                  email: abril.terrazas@example.com
                  email2: null
                  email3: null
                  phone_mobile: '918 487907'
                  phone_number: '+34 960-86-2237'
                  phone_emergency: '+34 913-356606'
                  address: 'Paseo Victoria, 047, 85º A'
                  postal_code: '87543'
                  city: 'As Botello'
                  province: Sevilla
                  region: 'Comunidad de Madrid'
                  country: ''
                  photo: 'https://storage.googleapis.com/berrly-saas/bnonprofit/members/NcCbZ3oIaF-532223.jpg'
                  legal_name: null
                  industry: null
                  contact_name: null
                  contact_email: null
                  contact_phone: null
                  contact_position: null
                  web: null
                  linkedin: null
                  twitter: null
                  facebook: null
                  instagram: null
                  tiktok: null
                  telegram: null
                  skype: null
                  subscription_date: '2014-09-29T00:00:00.000000Z'
                  unsubscription_date: null
                  tags:
                    - socio-con-empresa
                    - forma-parte-de-colectivo
                    - cargo-en-cuenta
                    - impagos
                    - cuota-premium
                  extra_fields:
                    -
                      id_field_schema: 3114
                      id_organization: 1788
                      id_field_category: 1088
                      order: 0
                      name: 'Periodicidad de pago'
                      type: DROPDOWN-FIXED
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 3136
                      id_organization: 1788
                      id_field_category: 1088
                      order: 0
                      name: 'Nombre familiar'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 3630
                      id_organization: 1788
                      id_field_category: 1088
                      order: 0
                      name: Preferencias
                      type: DROPDOWN
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 3888
                      id_organization: 1788
                      id_field_category: null
                      order: 0
                      name: Seccions
                      type: DROPDOWN-FIXED
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4075
                      id_organization: 1788
                      id_field_category: null
                      order: 0
                      name: Cursos
                      type: DROPDOWN-MULTIPLE-FIXED
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4088
                      id_organization: 1788
                      id_field_category: null
                      order: 0
                      name: 'Àrea d''interès'
                      type: DROPDOWN-MULTIPLE-FIXED
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4305
                      id_organization: 1788
                      id_field_category: null
                      order: 0
                      name: 'Nombre de la familia (apellidos niño)'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4306
                      id_organization: 1788
                      id_field_category: null
                      order: 0
                      name: 'Justificante de pago'
                      type: FILE
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4860
                      id_organization: 1788
                      id_field_category: 1468
                      order: 0
                      name: 'Comprobant sol.licitut beca'
                      type: FILE
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4888
                      id_organization: 1788
                      id_field_category: 1468
                      order: 0
                      name: 'Fotocòpia del NIF o NIE de la persona que fa la inscripció'
                      type: FILE
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4889
                      id_organization: 1788
                      id_field_category: 1468
                      order: 0
                      name: 'Fotocòpia de la targeta sanitària (CatSalut) o mútua de l’infant'
                      type: FILE
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4890
                      id_organization: 1788
                      id_field_category: 1468
                      order: 0
                      name: 'Fotocòpia de la cartilla de vacunacions de l’infant'
                      type: FILE
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4891
                      id_organization: 1788
                      id_field_category: 1469
                      order: 0
                      name: 'Nom i cognoms Pare/ Mare/ Tutor legal'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4892
                      id_organization: 1788
                      id_field_category: 1469
                      order: 0
                      name: 'NIF o NIE Pare/ Mare/ Tutor legal'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4893
                      id_organization: 1788
                      id_field_category: 1470
                      order: 0
                      name: 'Nom autoritzat 1'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4894
                      id_organization: 1788
                      id_field_category: 1470
                      order: 0
                      name: 'DNI autoritzat 1'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4895
                      id_organization: 1788
                      id_field_category: 1470
                      order: 0
                      name: 'Nom autoritzat 2'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4896
                      id_organization: 1788
                      id_field_category: 1470
                      order: 0
                      name: 'DNI autoritzat 2'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4897
                      id_organization: 1788
                      id_field_category: 1470
                      order: 0
                      name: 'Nom autoritzat 3'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4898
                      id_organization: 1788
                      id_field_category: 1470
                      order: 0
                      name: 'DNI autoritzat 3'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4899
                      id_organization: 1788
                      id_field_category: 1199
                      order: 0
                      name: 'Autorització subministrament de Paracetamol'
                      type: BOOLEAN
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4900
                      id_organization: 1788
                      id_field_category: 1471
                      order: 0
                      name: 'Indiqueu si pateix algun tipus d’alteració física o psíquica'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4901
                      id_organization: 1788
                      id_field_category: 1471
                      order: 0
                      name: 'Indiqueu si pateix alguna malaltia crònica'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4902
                      id_organization: 1788
                      id_field_category: 1471
                      order: 0
                      name: 'Indiqueu si pren algun medicament de forma periòdica'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4903
                      id_organization: 1788
                      id_field_category: 1471
                      order: 0
                      name: 'Indiqueu si pateix algun tipus d’al·lèrgia'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4904
                      id_organization: 1788
                      id_field_category: 1471
                      order: 0
                      name: 'Indiqueu qualsevol observació rellevant sobre l’alimentació'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4906
                      id_organization: 1788
                      id_field_category: 1088
                      order: 0
                      name: 'Tipo de socio'
                      type: DROPDOWN
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4907
                      id_organization: 1788
                      id_field_category: 1088
                      order: 0
                      name: 'Indica la cantidad si quieres hacer una aportación extra (€)'
                      type: NUMBER
                      visible: true
                      sort: true
                      translations: null
                      data: null
                  media: []
                  shared_media:
                    -
                      id: 60934
                      id_organization: 1788
                      model_type: App\Organization
                      model_id: 1788
                      collection_name: documents
                      name: 'Berrly - Asociaciones y Federaciones'
                      file_name: 9g9j67WX-Berrly---Asociaciones-y-Federaciones.pdf
                      mime_type: application/pdf
                      disk: gcs
                      size: 2565993
                      manipulations: []
                      custom_properties:
                        tags:
                          - proyecto-a
                        member_tags:
                          - socio-con-empresa
                      responsive_images: []
                      order_column: 56372
                      created_at: '2023-01-05T11:20:19.000000Z'
                      updated_at: '2023-01-05T11:20:19.000000Z'
                      url: 'https://storage.googleapis.com/berrly-saas/bnonprofit/documents/9g9j67WX-Berrly---Asociaciones-y-Federaciones.pdf'
                    -
                      id: 65358
                      id_organization: 1788
                      model_type: App\Organization
                      model_id: 1788
                      collection_name: documents
                      name: 'Berrly - Clubs esportius - CA'
                      file_name: jXfu5vZ3-Berrly---Clubs-esportius---CA.pdf
                      mime_type: application/pdf
                      disk: gcs
                      size: 7123622
                      manipulations: []
                      custom_properties:
                        tags:
                          - proyecto-a
                        member_tags:
                          - socio-con-empresa
                      responsive_images: []
                      order_column: 60290
                      created_at: '2023-01-31T16:02:01.000000Z'
                      updated_at: '2023-01-31T16:02:01.000000Z'
                      url: 'https://storage.googleapis.com/berrly-saas/bnonprofit/documents/jXfu5vZ3-Berrly---Clubs-esportius---CA.pdf'
                  tokens:
                    -
                      id_token: 385022
                      id_member: 532223
                      id_card_design: null
                      token: sH3jXj66hTPI0UJ4V1hv8hHv
                      type: MEMBERZONE
                      enabled: true
                      created_at: '2023-02-23T12:45:37.000000Z'
                      updated_at: null
                      expire_at: null
                      deleted_at: null
                    -
                      id_token: 457473
                      id_member: 532223
                      id_card_design: 520
                      token: OZFLTgOB4JMcYPlwvA4vfWWK
                      type: MEMBERCARD
                      enabled: true
                      created_at: '2023-06-09T08:18:34.000000Z'
                      updated_at: '2023-06-09T08:18:34.000000Z'
                      expire_at: null
                      deleted_at: null
                properties:
                  id_member:
                    type: integer
                    example: 532223
                  id_member_update:
                    type: string
                    example: null
                  type:
                    type: string
                    example: MEMBER
                  entity_type:
                    type: string
                    example: INDIVIDUAL
                  num_member:
                    type: integer
                    example: 34
                  national_id_number:
                    type: string
                    example: 40761663M
                  national_id_type:
                    type: string
                    example: DNI
                  name:
                    type: string
                    example: Abril
                  last_name:
                    type: string
                    example: 'Terrazas Alanis'
                  fname:
                    type: string
                    example: ''
                  alias:
                    type: string
                    example: ''
                  gender:
                    type: string
                    example: null
                  birthdate:
                    type: string
                    example: null
                  email:
                    type: string
                    example: abril.terrazas@example.com
                  email2:
                    type: string
                    example: null
                  email3:
                    type: string
                    example: null
                  phone_mobile:
                    type: string
                    example: '918 487907'
                  phone_number:
                    type: string
                    example: '+34 960-86-2237'
                  phone_emergency:
                    type: string
                    example: '+34 913-356606'
                  address:
                    type: string
                    example: 'Paseo Victoria, 047, 85º A'
                  postal_code:
                    type: string
                    example: '87543'
                  city:
                    type: string
                    example: 'As Botello'
                  province:
                    type: string
                    example: Sevilla
                  region:
                    type: string
                    example: 'Comunidad de Madrid'
                  country:
                    type: string
                    example: ''
                  photo:
                    type: string
                    example: 'https://storage.googleapis.com/berrly-saas/bnonprofit/members/NcCbZ3oIaF-532223.jpg'
                  legal_name:
                    type: string
                    example: null
                  industry:
                    type: string
                    example: null
                  contact_name:
                    type: string
                    example: null
                  contact_email:
                    type: string
                    example: null
                  contact_phone:
                    type: string
                    example: null
                  contact_position:
                    type: string
                    example: null
                  web:
                    type: string
                    example: null
                  linkedin:
                    type: string
                    example: null
                  twitter:
                    type: string
                    example: null
                  facebook:
                    type: string
                    example: null
                  instagram:
                    type: string
                    example: null
                  tiktok:
                    type: string
                    example: null
                  telegram:
                    type: string
                    example: null
                  skype:
                    type: string
                    example: null
                  subscription_date:
                    type: string
                    example: '2014-09-29T00:00:00.000000Z'
                  unsubscription_date:
                    type: string
                    example: null
                  tags:
                    type: array
                    example:
                      - socio-con-empresa
                      - forma-parte-de-colectivo
                      - cargo-en-cuenta
                      - impagos
                      - cuota-premium
                    items:
                      type: string
                  extra_fields:
                    type: array
                    example:
                      -
                        id_field_schema: 3114
                        id_organization: 1788
                        id_field_category: 1088
                        order: 0
                        name: 'Periodicidad de pago'
                        type: DROPDOWN-FIXED
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 3136
                        id_organization: 1788
                        id_field_category: 1088
                        order: 0
                        name: 'Nombre familiar'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 3630
                        id_organization: 1788
                        id_field_category: 1088
                        order: 0
                        name: Preferencias
                        type: DROPDOWN
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 3888
                        id_organization: 1788
                        id_field_category: null
                        order: 0
                        name: Seccions
                        type: DROPDOWN-FIXED
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4075
                        id_organization: 1788
                        id_field_category: null
                        order: 0
                        name: Cursos
                        type: DROPDOWN-MULTIPLE-FIXED
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4088
                        id_organization: 1788
                        id_field_category: null
                        order: 0
                        name: 'Àrea d''interès'
                        type: DROPDOWN-MULTIPLE-FIXED
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4305
                        id_organization: 1788
                        id_field_category: null
                        order: 0
                        name: 'Nombre de la familia (apellidos niño)'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4306
                        id_organization: 1788
                        id_field_category: null
                        order: 0
                        name: 'Justificante de pago'
                        type: FILE
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4860
                        id_organization: 1788
                        id_field_category: 1468
                        order: 0
                        name: 'Comprobant sol.licitut beca'
                        type: FILE
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4888
                        id_organization: 1788
                        id_field_category: 1468
                        order: 0
                        name: 'Fotocòpia del NIF o NIE de la persona que fa la inscripció'
                        type: FILE
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4889
                        id_organization: 1788
                        id_field_category: 1468
                        order: 0
                        name: 'Fotocòpia de la targeta sanitària (CatSalut) o mútua de l’infant'
                        type: FILE
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4890
                        id_organization: 1788
                        id_field_category: 1468
                        order: 0
                        name: 'Fotocòpia de la cartilla de vacunacions de l’infant'
                        type: FILE
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4891
                        id_organization: 1788
                        id_field_category: 1469
                        order: 0
                        name: 'Nom i cognoms Pare/ Mare/ Tutor legal'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4892
                        id_organization: 1788
                        id_field_category: 1469
                        order: 0
                        name: 'NIF o NIE Pare/ Mare/ Tutor legal'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4893
                        id_organization: 1788
                        id_field_category: 1470
                        order: 0
                        name: 'Nom autoritzat 1'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4894
                        id_organization: 1788
                        id_field_category: 1470
                        order: 0
                        name: 'DNI autoritzat 1'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4895
                        id_organization: 1788
                        id_field_category: 1470
                        order: 0
                        name: 'Nom autoritzat 2'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4896
                        id_organization: 1788
                        id_field_category: 1470
                        order: 0
                        name: 'DNI autoritzat 2'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4897
                        id_organization: 1788
                        id_field_category: 1470
                        order: 0
                        name: 'Nom autoritzat 3'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4898
                        id_organization: 1788
                        id_field_category: 1470
                        order: 0
                        name: 'DNI autoritzat 3'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4899
                        id_organization: 1788
                        id_field_category: 1199
                        order: 0
                        name: 'Autorització subministrament de Paracetamol'
                        type: BOOLEAN
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4900
                        id_organization: 1788
                        id_field_category: 1471
                        order: 0
                        name: 'Indiqueu si pateix algun tipus d’alteració física o psíquica'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4901
                        id_organization: 1788
                        id_field_category: 1471
                        order: 0
                        name: 'Indiqueu si pateix alguna malaltia crònica'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4902
                        id_organization: 1788
                        id_field_category: 1471
                        order: 0
                        name: 'Indiqueu si pren algun medicament de forma periòdica'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4903
                        id_organization: 1788
                        id_field_category: 1471
                        order: 0
                        name: 'Indiqueu si pateix algun tipus d’al·lèrgia'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4904
                        id_organization: 1788
                        id_field_category: 1471
                        order: 0
                        name: 'Indiqueu qualsevol observació rellevant sobre l’alimentació'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4906
                        id_organization: 1788
                        id_field_category: 1088
                        order: 0
                        name: 'Tipo de socio'
                        type: DROPDOWN
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4907
                        id_organization: 1788
                        id_field_category: 1088
                        order: 0
                        name: 'Indica la cantidad si quieres hacer una aportación extra (€)'
                        type: NUMBER
                        visible: true
                        sort: true
                        translations: null
                        data: null
                    items:
                      type: object
                      properties:
                        id_field_schema:
                          type: integer
                          example: 3114
                        id_organization:
                          type: integer
                          example: 1788
                        id_field_category:
                          type: integer
                          example: 1088
                        order:
                          type: integer
                          example: 0
                        name:
                          type: string
                          example: 'Periodicidad de pago'
                        type:
                          type: string
                          example: DROPDOWN-FIXED
                        visible:
                          type: boolean
                          example: true
                        sort:
                          type: boolean
                          example: true
                        translations:
                          type: string
                          example: null
                        data:
                          type: string
                          example: null
                  media:
                    type: array
                    example: []
                  shared_media:
                    type: array
                    example:
                      -
                        id: 60934
                        id_organization: 1788
                        model_type: App\Organization
                        model_id: 1788
                        collection_name: documents
                        name: 'Berrly - Asociaciones y Federaciones'
                        file_name: 9g9j67WX-Berrly---Asociaciones-y-Federaciones.pdf
                        mime_type: application/pdf
                        disk: gcs
                        size: 2565993
                        manipulations: []
                        custom_properties:
                          tags:
                            - proyecto-a
                          member_tags:
                            - socio-con-empresa
                        responsive_images: []
                        order_column: 56372
                        created_at: '2023-01-05T11:20:19.000000Z'
                        updated_at: '2023-01-05T11:20:19.000000Z'
                        url: 'https://storage.googleapis.com/berrly-saas/bnonprofit/documents/9g9j67WX-Berrly---Asociaciones-y-Federaciones.pdf'
                      -
                        id: 65358
                        id_organization: 1788
                        model_type: App\Organization
                        model_id: 1788
                        collection_name: documents
                        name: 'Berrly - Clubs esportius - CA'
                        file_name: jXfu5vZ3-Berrly---Clubs-esportius---CA.pdf
                        mime_type: application/pdf
                        disk: gcs
                        size: 7123622
                        manipulations: []
                        custom_properties:
                          tags:
                            - proyecto-a
                          member_tags:
                            - socio-con-empresa
                        responsive_images: []
                        order_column: 60290
                        created_at: '2023-01-31T16:02:01.000000Z'
                        updated_at: '2023-01-31T16:02:01.000000Z'
                        url: 'https://storage.googleapis.com/berrly-saas/bnonprofit/documents/jXfu5vZ3-Berrly---Clubs-esportius---CA.pdf'
                    items:
                      type: object
                      properties:
                        id:
                          type: integer
                          example: 60934
                        id_organization:
                          type: integer
                          example: 1788
                        model_type:
                          type: string
                          example: App\Organization
                        model_id:
                          type: integer
                          example: 1788
                        collection_name:
                          type: string
                          example: documents
                        name:
                          type: string
                          example: 'Berrly - Asociaciones y Federaciones'
                        file_name:
                          type: string
                          example: 9g9j67WX-Berrly---Asociaciones-y-Federaciones.pdf
                        mime_type:
                          type: string
                          example: application/pdf
                        disk:
                          type: string
                          example: gcs
                        size:
                          type: integer
                          example: 2565993
                        manipulations:
                          type: array
                          example: []
                        custom_properties:
                          type: object
                          properties:
                            tags:
                              type: array
                              example:
                                - proyecto-a
                              items:
                                type: string
                            member_tags:
                              type: array
                              example:
                                - socio-con-empresa
                              items:
                                type: string
                        responsive_images:
                          type: array
                          example: []
                        order_column:
                          type: integer
                          example: 56372
                        created_at:
                          type: string
                          example: '2023-01-05T11:20:19.000000Z'
                        updated_at:
                          type: string
                          example: '2023-01-05T11:20:19.000000Z'
                        url:
                          type: string
                          example: 'https://storage.googleapis.com/berrly-saas/bnonprofit/documents/9g9j67WX-Berrly---Asociaciones-y-Federaciones.pdf'
                  tokens:
                    type: array
                    example:
                      -
                        id_token: 385022
                        id_member: 532223
                        id_card_design: null
                        token: sH3jXj66hTPI0UJ4V1hv8hHv
                        type: MEMBERZONE
                        enabled: true
                        created_at: '2023-02-23T12:45:37.000000Z'
                        updated_at: null
                        expire_at: null
                        deleted_at: null
                      -
                        id_token: 457473
                        id_member: 532223
                        id_card_design: 520
                        token: OZFLTgOB4JMcYPlwvA4vfWWK
                        type: MEMBERCARD
                        enabled: true
                        created_at: '2023-06-09T08:18:34.000000Z'
                        updated_at: '2023-06-09T08:18:34.000000Z'
                        expire_at: null
                        deleted_at: null
                    items:
                      type: object
                      properties:
                        id_token:
                          type: integer
                          example: 385022
                        id_member:
                          type: integer
                          example: 532223
                        id_card_design:
                          type: string
                          example: null
                        token:
                          type: string
                          example: sH3jXj66hTPI0UJ4V1hv8hHv
                        type:
                          type: string
                          example: MEMBERZONE
                        enabled:
                          type: boolean
                          example: true
                        created_at:
                          type: string
                          example: '2023-02-23T12:45:37.000000Z'
                        updated_at:
                          type: string
                          example: null
                        expire_at:
                          type: string
                          example: null
                        deleted_at:
                          type: string
                          example: null
      tags:
        - Members
    post:
      summary: Update
      operationId: update
      description: 'Updates a member if id_member is specified.'
      parameters: []
      responses:
        200:
          description: ''
          content:
            application/json:
              schema:
                type: object
                example:
                  id_member: 532223
                  id_member_update: null
                  type: MEMBER
                  entity_type: INDIVIDUAL
                  num_member: 34
                  national_id_number: 40761663M
                  national_id_type: DNI
                  name: Abril
                  last_name: 'Terrazas Alanis'
                  fname: ''
                  alias: ''
                  gender: null
                  birthdate: null
                  email: abril.terrazas@example.com
                  email2: null
                  email3: null
                  phone_mobile: '918 487907'
                  phone_number: '+34 960-86-2237'
                  phone_emergency: '+34 913-356606'
                  address: 'Paseo Victoria, 047, 85º A'
                  postal_code: '87543'
                  city: 'As Botello'
                  province: Sevilla
                  region: 'Comunidad de Madrid'
                  country: ''
                  photo: 'https://storage.googleapis.com/berrly-saas/bnonprofit/members/NcCbZ3oIaF-532223.jpg'
                  legal_name: null
                  industry: null
                  contact_name: null
                  contact_email: null
                  contact_phone: null
                  contact_position: null
                  web: null
                  linkedin: null
                  twitter: null
                  facebook: null
                  instagram: null
                  tiktok: null
                  telegram: null
                  skype: null
                  subscription_date: '2014-09-29T00:00:00.000000Z'
                  unsubscription_date: null
                  tags:
                    - socio-con-empresa
                    - forma-parte-de-colectivo
                    - cargo-en-cuenta
                    - impagos
                    - cuota-premium
                  extra_fields:
                    -
                      id_field_schema: 3114
                      id_organization: 1788
                      id_field_category: 1088
                      order: 0
                      name: 'Periodicidad de pago'
                      type: DROPDOWN-FIXED
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 3136
                      id_organization: 1788
                      id_field_category: 1088
                      order: 0
                      name: 'Nombre familiar'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 3630
                      id_organization: 1788
                      id_field_category: 1088
                      order: 0
                      name: Preferencias
                      type: DROPDOWN
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 3888
                      id_organization: 1788
                      id_field_category: null
                      order: 0
                      name: Seccions
                      type: DROPDOWN-FIXED
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4075
                      id_organization: 1788
                      id_field_category: null
                      order: 0
                      name: Cursos
                      type: DROPDOWN-MULTIPLE-FIXED
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4088
                      id_organization: 1788
                      id_field_category: null
                      order: 0
                      name: 'Àrea d''interès'
                      type: DROPDOWN-MULTIPLE-FIXED
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4305
                      id_organization: 1788
                      id_field_category: null
                      order: 0
                      name: 'Nombre de la familia (apellidos niño)'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4306
                      id_organization: 1788
                      id_field_category: null
                      order: 0
                      name: 'Justificante de pago'
                      type: FILE
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4860
                      id_organization: 1788
                      id_field_category: 1468
                      order: 0
                      name: 'Comprobant sol.licitut beca'
                      type: FILE
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4888
                      id_organization: 1788
                      id_field_category: 1468
                      order: 0
                      name: 'Fotocòpia del NIF o NIE de la persona que fa la inscripció'
                      type: FILE
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4889
                      id_organization: 1788
                      id_field_category: 1468
                      order: 0
                      name: 'Fotocòpia de la targeta sanitària (CatSalut) o mútua de l’infant'
                      type: FILE
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4890
                      id_organization: 1788
                      id_field_category: 1468
                      order: 0
                      name: 'Fotocòpia de la cartilla de vacunacions de l’infant'
                      type: FILE
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4891
                      id_organization: 1788
                      id_field_category: 1469
                      order: 0
                      name: 'Nom i cognoms Pare/ Mare/ Tutor legal'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4892
                      id_organization: 1788
                      id_field_category: 1469
                      order: 0
                      name: 'NIF o NIE Pare/ Mare/ Tutor legal'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4893
                      id_organization: 1788
                      id_field_category: 1470
                      order: 0
                      name: 'Nom autoritzat 1'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4894
                      id_organization: 1788
                      id_field_category: 1470
                      order: 0
                      name: 'DNI autoritzat 1'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4895
                      id_organization: 1788
                      id_field_category: 1470
                      order: 0
                      name: 'Nom autoritzat 2'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4896
                      id_organization: 1788
                      id_field_category: 1470
                      order: 0
                      name: 'DNI autoritzat 2'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4897
                      id_organization: 1788
                      id_field_category: 1470
                      order: 0
                      name: 'Nom autoritzat 3'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4898
                      id_organization: 1788
                      id_field_category: 1470
                      order: 0
                      name: 'DNI autoritzat 3'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4899
                      id_organization: 1788
                      id_field_category: 1199
                      order: 0
                      name: 'Autorització subministrament de Paracetamol'
                      type: BOOLEAN
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4900
                      id_organization: 1788
                      id_field_category: 1471
                      order: 0
                      name: 'Indiqueu si pateix algun tipus d’alteració física o psíquica'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4901
                      id_organization: 1788
                      id_field_category: 1471
                      order: 0
                      name: 'Indiqueu si pateix alguna malaltia crònica'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4902
                      id_organization: 1788
                      id_field_category: 1471
                      order: 0
                      name: 'Indiqueu si pren algun medicament de forma periòdica'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4903
                      id_organization: 1788
                      id_field_category: 1471
                      order: 0
                      name: 'Indiqueu si pateix algun tipus d’al·lèrgia'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4904
                      id_organization: 1788
                      id_field_category: 1471
                      order: 0
                      name: 'Indiqueu qualsevol observació rellevant sobre l’alimentació'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4906
                      id_organization: 1788
                      id_field_category: 1088
                      order: 0
                      name: 'Tipo de socio'
                      type: DROPDOWN
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4907
                      id_organization: 1788
                      id_field_category: 1088
                      order: 0
                      name: 'Indica la cantidad si quieres hacer una aportación extra (€)'
                      type: NUMBER
                      visible: true
                      sort: true
                      translations: null
                      data: null
                  media: []
                  shared_media:
                    -
                      id: 60934
                      id_organization: 1788
                      model_type: App\Organization
                      model_id: 1788
                      collection_name: documents
                      name: 'Berrly - Asociaciones y Federaciones'
                      file_name: 9g9j67WX-Berrly---Asociaciones-y-Federaciones.pdf
                      mime_type: application/pdf
                      disk: gcs
                      size: 2565993
                      manipulations: []
                      custom_properties:
                        tags:
                          - proyecto-a
                        member_tags:
                          - socio-con-empresa
                      responsive_images: []
                      order_column: 56372
                      created_at: '2023-01-05T11:20:19.000000Z'
                      updated_at: '2023-01-05T11:20:19.000000Z'
                      url: 'https://storage.googleapis.com/berrly-saas/bnonprofit/documents/9g9j67WX-Berrly---Asociaciones-y-Federaciones.pdf'
                    -
                      id: 65358
                      id_organization: 1788
                      model_type: App\Organization
                      model_id: 1788
                      collection_name: documents
                      name: 'Berrly - Clubs esportius - CA'
                      file_name: jXfu5vZ3-Berrly---Clubs-esportius---CA.pdf
                      mime_type: application/pdf
                      disk: gcs
                      size: 7123622
                      manipulations: []
                      custom_properties:
                        tags:
                          - proyecto-a
                        member_tags:
                          - socio-con-empresa
                      responsive_images: []
                      order_column: 60290
                      created_at: '2023-01-31T16:02:01.000000Z'
                      updated_at: '2023-01-31T16:02:01.000000Z'
                      url: 'https://storage.googleapis.com/berrly-saas/bnonprofit/documents/jXfu5vZ3-Berrly---Clubs-esportius---CA.pdf'
                  tokens:
                    -
                      id_token: 385022
                      id_member: 532223
                      id_card_design: null
                      token: sH3jXj66hTPI0UJ4V1hv8hHv
                      type: MEMBERZONE
                      enabled: true
                      created_at: '2023-02-23T12:45:37.000000Z'
                      updated_at: null
                      expire_at: null
                      deleted_at: null
                    -
                      id_token: 457473
                      id_member: 532223
                      id_card_design: 520
                      token: OZFLTgOB4JMcYPlwvA4vfWWK
                      type: MEMBERCARD
                      enabled: true
                      created_at: '2023-06-09T08:18:34.000000Z'
                      updated_at: '2023-06-09T08:18:34.000000Z'
                      expire_at: null
                      deleted_at: null
                properties:
                  id_member:
                    type: integer
                    example: 532223
                  id_member_update:
                    type: string
                    example: null
                  type:
                    type: string
                    example: MEMBER
                  entity_type:
                    type: string
                    example: INDIVIDUAL
                  num_member:
                    type: integer
                    example: 34
                  national_id_number:
                    type: string
                    example: 40761663M
                  national_id_type:
                    type: string
                    example: DNI
                  name:
                    type: string
                    example: Abril
                  last_name:
                    type: string
                    example: 'Terrazas Alanis'
                  fname:
                    type: string
                    example: ''
                  alias:
                    type: string
                    example: ''
                  gender:
                    type: string
                    example: null
                  birthdate:
                    type: string
                    example: null
                  email:
                    type: string
                    example: abril.terrazas@example.com
                  email2:
                    type: string
                    example: null
                  email3:
                    type: string
                    example: null
                  phone_mobile:
                    type: string
                    example: '918 487907'
                  phone_number:
                    type: string
                    example: '+34 960-86-2237'
                  phone_emergency:
                    type: string
                    example: '+34 913-356606'
                  address:
                    type: string
                    example: 'Paseo Victoria, 047, 85º A'
                  postal_code:
                    type: string
                    example: '87543'
                  city:
                    type: string
                    example: 'As Botello'
                  province:
                    type: string
                    example: Sevilla
                  region:
                    type: string
                    example: 'Comunidad de Madrid'
                  country:
                    type: string
                    example: ''
                  photo:
                    type: string
                    example: 'https://storage.googleapis.com/berrly-saas/bnonprofit/members/NcCbZ3oIaF-532223.jpg'
                  legal_name:
                    type: string
                    example: null
                  industry:
                    type: string
                    example: null
                  contact_name:
                    type: string
                    example: null
                  contact_email:
                    type: string
                    example: null
                  contact_phone:
                    type: string
                    example: null
                  contact_position:
                    type: string
                    example: null
                  web:
                    type: string
                    example: null
                  linkedin:
                    type: string
                    example: null
                  twitter:
                    type: string
                    example: null
                  facebook:
                    type: string
                    example: null
                  instagram:
                    type: string
                    example: null
                  tiktok:
                    type: string
                    example: null
                  telegram:
                    type: string
                    example: null
                  skype:
                    type: string
                    example: null
                  subscription_date:
                    type: string
                    example: '2014-09-29T00:00:00.000000Z'
                  unsubscription_date:
                    type: string
                    example: null
                  tags:
                    type: array
                    example:
                      - socio-con-empresa
                      - forma-parte-de-colectivo
                      - cargo-en-cuenta
                      - impagos
                      - cuota-premium
                    items:
                      type: string
                  extra_fields:
                    type: array
                    example:
                      -
                        id_field_schema: 3114
                        id_organization: 1788
                        id_field_category: 1088
                        order: 0
                        name: 'Periodicidad de pago'
                        type: DROPDOWN-FIXED
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 3136
                        id_organization: 1788
                        id_field_category: 1088
                        order: 0
                        name: 'Nombre familiar'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 3630
                        id_organization: 1788
                        id_field_category: 1088
                        order: 0
                        name: Preferencias
                        type: DROPDOWN
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 3888
                        id_organization: 1788
                        id_field_category: null
                        order: 0
                        name: Seccions
                        type: DROPDOWN-FIXED
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4075
                        id_organization: 1788
                        id_field_category: null
                        order: 0
                        name: Cursos
                        type: DROPDOWN-MULTIPLE-FIXED
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4088
                        id_organization: 1788
                        id_field_category: null
                        order: 0
                        name: 'Àrea d''interès'
                        type: DROPDOWN-MULTIPLE-FIXED
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4305
                        id_organization: 1788
                        id_field_category: null
                        order: 0
                        name: 'Nombre de la familia (apellidos niño)'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4306
                        id_organization: 1788
                        id_field_category: null
                        order: 0
                        name: 'Justificante de pago'
                        type: FILE
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4860
                        id_organization: 1788
                        id_field_category: 1468
                        order: 0
                        name: 'Comprobant sol.licitut beca'
                        type: FILE
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4888
                        id_organization: 1788
                        id_field_category: 1468
                        order: 0
                        name: 'Fotocòpia del NIF o NIE de la persona que fa la inscripció'
                        type: FILE
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4889
                        id_organization: 1788
                        id_field_category: 1468
                        order: 0
                        name: 'Fotocòpia de la targeta sanitària (CatSalut) o mútua de l’infant'
                        type: FILE
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4890
                        id_organization: 1788
                        id_field_category: 1468
                        order: 0
                        name: 'Fotocòpia de la cartilla de vacunacions de l’infant'
                        type: FILE
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4891
                        id_organization: 1788
                        id_field_category: 1469
                        order: 0
                        name: 'Nom i cognoms Pare/ Mare/ Tutor legal'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4892
                        id_organization: 1788
                        id_field_category: 1469
                        order: 0
                        name: 'NIF o NIE Pare/ Mare/ Tutor legal'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4893
                        id_organization: 1788
                        id_field_category: 1470
                        order: 0
                        name: 'Nom autoritzat 1'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4894
                        id_organization: 1788
                        id_field_category: 1470
                        order: 0
                        name: 'DNI autoritzat 1'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4895
                        id_organization: 1788
                        id_field_category: 1470
                        order: 0
                        name: 'Nom autoritzat 2'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4896
                        id_organization: 1788
                        id_field_category: 1470
                        order: 0
                        name: 'DNI autoritzat 2'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4897
                        id_organization: 1788
                        id_field_category: 1470
                        order: 0
                        name: 'Nom autoritzat 3'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4898
                        id_organization: 1788
                        id_field_category: 1470
                        order: 0
                        name: 'DNI autoritzat 3'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4899
                        id_organization: 1788
                        id_field_category: 1199
                        order: 0
                        name: 'Autorització subministrament de Paracetamol'
                        type: BOOLEAN
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4900
                        id_organization: 1788
                        id_field_category: 1471
                        order: 0
                        name: 'Indiqueu si pateix algun tipus d’alteració física o psíquica'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4901
                        id_organization: 1788
                        id_field_category: 1471
                        order: 0
                        name: 'Indiqueu si pateix alguna malaltia crònica'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4902
                        id_organization: 1788
                        id_field_category: 1471
                        order: 0
                        name: 'Indiqueu si pren algun medicament de forma periòdica'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4903
                        id_organization: 1788
                        id_field_category: 1471
                        order: 0
                        name: 'Indiqueu si pateix algun tipus d’al·lèrgia'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4904
                        id_organization: 1788
                        id_field_category: 1471
                        order: 0
                        name: 'Indiqueu qualsevol observació rellevant sobre l’alimentació'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4906
                        id_organization: 1788
                        id_field_category: 1088
                        order: 0
                        name: 'Tipo de socio'
                        type: DROPDOWN
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4907
                        id_organization: 1788
                        id_field_category: 1088
                        order: 0
                        name: 'Indica la cantidad si quieres hacer una aportación extra (€)'
                        type: NUMBER
                        visible: true
                        sort: true
                        translations: null
                        data: null
                    items:
                      type: object
                      properties:
                        id_field_schema:
                          type: integer
                          example: 3114
                        id_organization:
                          type: integer
                          example: 1788
                        id_field_category:
                          type: integer
                          example: 1088
                        order:
                          type: integer
                          example: 0
                        name:
                          type: string
                          example: 'Periodicidad de pago'
                        type:
                          type: string
                          example: DROPDOWN-FIXED
                        visible:
                          type: boolean
                          example: true
                        sort:
                          type: boolean
                          example: true
                        translations:
                          type: string
                          example: null
                        data:
                          type: string
                          example: null
                  media:
                    type: array
                    example: []
                  shared_media:
                    type: array
                    example:
                      -
                        id: 60934
                        id_organization: 1788
                        model_type: App\Organization
                        model_id: 1788
                        collection_name: documents
                        name: 'Berrly - Asociaciones y Federaciones'
                        file_name: 9g9j67WX-Berrly---Asociaciones-y-Federaciones.pdf
                        mime_type: application/pdf
                        disk: gcs
                        size: 2565993
                        manipulations: []
                        custom_properties:
                          tags:
                            - proyecto-a
                          member_tags:
                            - socio-con-empresa
                        responsive_images: []
                        order_column: 56372
                        created_at: '2023-01-05T11:20:19.000000Z'
                        updated_at: '2023-01-05T11:20:19.000000Z'
                        url: 'https://storage.googleapis.com/berrly-saas/bnonprofit/documents/9g9j67WX-Berrly---Asociaciones-y-Federaciones.pdf'
                      -
                        id: 65358
                        id_organization: 1788
                        model_type: App\Organization
                        model_id: 1788
                        collection_name: documents
                        name: 'Berrly - Clubs esportius - CA'
                        file_name: jXfu5vZ3-Berrly---Clubs-esportius---CA.pdf
                        mime_type: application/pdf
                        disk: gcs
                        size: 7123622
                        manipulations: []
                        custom_properties:
                          tags:
                            - proyecto-a
                          member_tags:
                            - socio-con-empresa
                        responsive_images: []
                        order_column: 60290
                        created_at: '2023-01-31T16:02:01.000000Z'
                        updated_at: '2023-01-31T16:02:01.000000Z'
                        url: 'https://storage.googleapis.com/berrly-saas/bnonprofit/documents/jXfu5vZ3-Berrly---Clubs-esportius---CA.pdf'
                    items:
                      type: object
                      properties:
                        id:
                          type: integer
                          example: 60934
                        id_organization:
                          type: integer
                          example: 1788
                        model_type:
                          type: string
                          example: App\Organization
                        model_id:
                          type: integer
                          example: 1788
                        collection_name:
                          type: string
                          example: documents
                        name:
                          type: string
                          example: 'Berrly - Asociaciones y Federaciones'
                        file_name:
                          type: string
                          example: 9g9j67WX-Berrly---Asociaciones-y-Federaciones.pdf
                        mime_type:
                          type: string
                          example: application/pdf
                        disk:
                          type: string
                          example: gcs
                        size:
                          type: integer
                          example: 2565993
                        manipulations:
                          type: array
                          example: []
                        custom_properties:
                          type: object
                          properties:
                            tags:
                              type: array
                              example:
                                - proyecto-a
                              items:
                                type: string
                            member_tags:
                              type: array
                              example:
                                - socio-con-empresa
                              items:
                                type: string
                        responsive_images:
                          type: array
                          example: []
                        order_column:
                          type: integer
                          example: 56372
                        created_at:
                          type: string
                          example: '2023-01-05T11:20:19.000000Z'
                        updated_at:
                          type: string
                          example: '2023-01-05T11:20:19.000000Z'
                        url:
                          type: string
                          example: 'https://storage.googleapis.com/berrly-saas/bnonprofit/documents/9g9j67WX-Berrly---Asociaciones-y-Federaciones.pdf'
                  tokens:
                    type: array
                    example:
                      -
                        id_token: 385022
                        id_member: 532223
                        id_card_design: null
                        token: sH3jXj66hTPI0UJ4V1hv8hHv
                        type: MEMBERZONE
                        enabled: true
                        created_at: '2023-02-23T12:45:37.000000Z'
                        updated_at: null
                        expire_at: null
                        deleted_at: null
                      -
                        id_token: 457473
                        id_member: 532223
                        id_card_design: 520
                        token: OZFLTgOB4JMcYPlwvA4vfWWK
                        type: MEMBERCARD
                        enabled: true
                        created_at: '2023-06-09T08:18:34.000000Z'
                        updated_at: '2023-06-09T08:18:34.000000Z'
                        expire_at: null
                        deleted_at: null
                    items:
                      type: object
                      properties:
                        id_token:
                          type: integer
                          example: 385022
                        id_member:
                          type: integer
                          example: 532223
                        id_card_design:
                          type: string
                          example: null
                        token:
                          type: string
                          example: sH3jXj66hTPI0UJ4V1hv8hHv
                        type:
                          type: string
                          example: MEMBERZONE
                        enabled:
                          type: boolean
                          example: true
                        created_at:
                          type: string
                          example: '2023-02-23T12:45:37.000000Z'
                        updated_at:
                          type: string
                          example: null
                        expire_at:
                          type: string
                          example: null
                        deleted_at:
                          type: string
                          example: null
      tags:
        - Members
      requestBody:
        required: false
        content:
          application/json:
            schema:
              type: object
              properties:
                national_id_number:
                  type: string
                  description: 'National ID number value.'
                  example: 40761663M
                national_id_type:
                  type: string
                  description: 'National ID type value: CIF, DNI, NIE, PASSPORT, OTHER.'
                  example: DNI
                num_member:
                  type: integer
                  description: 'Num Member value.'
                  example: 342
                name:
                  type: string
                  description: 'Name value.'
                  example: Abril
                last_name:
                  type: string
                  description: 'Last name value.'
                  example: 'Terrazas Alanis'
                alias:
                  type: string
                  description: 'Alias value.'
                  example: Cerral
                gender:
                  type: string
                  description: 'MALE, FEMALE, "Any option you can write" value.'
                  example: FEMALE
                birthdate:
                  type: string
                  description: 'Birthdate value.'
                  example: '1983-06-24'
                email:
                  type: string
                  description: 'Email value.'
                  example: abrilterrazas@example.com
                email2:
                  type: string
                  description: 'Email value.'
                  example: abrilterrazas2@example.com
                email3:
                  type: string
                  description: 'Email value.'
                  example: terrazi83@example.com
                phone_mobile:
                  type: string
                  description: 'Phone mobile value.'
                  example: '+34666000000'
                phone_number:
                  type: string
                  description: 'Phone number value.'
                  example: '+34933456789'
                phone_emergency:
                  type: string
                  description: 'Phone emergency number value.'
                  example: '+34933456789'
                address:
                  type: string
                  description: 'Address value.'
                  example: 'Paseo Victoria, 047, 85º A'
                postal_code:
                  type: string
                  description: 'Postal code value.'
                  example: '87543'
                city:
                  type: string
                  description: 'City value.'
                  example: Sevilla
                province:
                  type: string
                  description: 'Province value.'
                  example: Sevilla
                region:
                  type: string
                  description: 'Region value.'
                  example: Andalucia
                country:
                  type: string
                  description: 'Country value.'
                  example: Spain
                comments:
                  type: string
                  description: 'Comments value.'
                  example: null
                legal_name:
                  type: string
                  description: 'Legal name value.'
                  example: null
                industry:
                  type: string
                  description: 'Industry value.'
                  example: null
                contact_name:
                  type: string.
                  description: ''
                  example: null
                contact_email:
                  type: string.
                  description: ''
                  example: null
                contact_phone:
                  type: string.
                  description: ''
                  example: null
                contact_position:
                  type: string.
                  description: ''
                  example: null
                web:
                  type: string.
                  description: ''
                  example: null
                linkedin:
                  type: string.
                  description: ''
                  example: null
                facebook:
                  type: string.
                  description: ''
                  example: null
                instagram:
                  type: string.
                  description: ''
                  example: null
                tiktok:
                  type: string.
                  description: ''
                  example: null
                telegram:
                  type: string.
                  description: ''
                  example: null
                skype:
                  type: string.
                  description: ''
                  example: null
                iban:
                  type: string.
                  description: ''
                  example: null
                payment_method:
                  type: string.
                  description: ''
                  example: null
                iban_name:
                  type: string.
                  description: ''
                  example: null
                bic:
                  type: string.
                  description: ''
                  example: null
                membership_fee:
                  type: string.
                  description: ''
                  example: null
                subscription_date:
                  type: string.
                  description: 'Date when member was first subscribed to organization.'
                  example: '2003-09-24'
    parameters:
      -
        in: path
        name: id_member
        description: 'The ID of the member:'
        example: 532223
        required: true
        schema:
          type: integer
  '/v1/members/token/{token}':
    get:
      summary: 'Get by Token'
      operationId: getByToken
      description: 'Display the specified member.'
      parameters: []
      responses:
        403:
          description: ''
          content:
            application/json:
              schema:
                type: object
                example:
                  error: 'Forbidden. Invalid Token.'
                properties:
                  error:
                    type: string
                    example: 'Forbidden. Invalid Token.'
      tags:
        - Members
    parameters:
      -
        in: path
        name: token
        description: 'the Token of the member.'
        example: i23yQp9HRsKVXrJMhhola78z
        required: true
        schema:
          type: string
  '/v1/members/national-id/{national_id_number}':
    get:
      summary: 'Get by National ID'
      operationId: getByNationalID
      description: 'Retrieve a member by their member number and national ID number. Member must have two values.'
      parameters: []
      responses:
        403:
          description: ''
          content:
            application/json:
              schema:
                type: object
                example:
                  error: 'Forbidden. Invalid Token.'
                properties:
                  error:
                    type: string
                    example: 'Forbidden. Invalid Token.'
      tags:
        - Members
    parameters:
      -
        in: path
        name: national_id_number
        description: 'The national ID number.'
        example: 40761663M
        required: true
        schema:
          type: string
  /v1/members:
    post:
      summary: Create
      operationId: create
      description: 'Create a new Member with given properties'
      parameters: []
      responses:
        200:
          description: ''
          content:
            application/json:
              schema:
                type: object
                example:
                  id_member: 532223
                  id_member_update: null
                  type: MEMBER
                  entity_type: INDIVIDUAL
                  num_member: 34
                  national_id_number: 40761663M
                  national_id_type: DNI
                  name: Abril
                  last_name: 'Terrazas Alanis'
                  fname: ''
                  alias: ''
                  gender: null
                  birthdate: null
                  email: abril.terrazas@example.com
                  email2: null
                  email3: null
                  phone_mobile: '918 487907'
                  phone_number: '+34 960-86-2237'
                  phone_emergency: '+34 913-356606'
                  address: 'Paseo Victoria, 047, 85º A'
                  postal_code: '87543'
                  city: 'As Botello'
                  province: Sevilla
                  region: 'Comunidad de Madrid'
                  country: ''
                  photo: 'https://storage.googleapis.com/berrly-saas/bnonprofit/members/NcCbZ3oIaF-532223.jpg'
                  legal_name: null
                  industry: null
                  contact_name: null
                  contact_email: null
                  contact_phone: null
                  contact_position: null
                  web: null
                  linkedin: null
                  twitter: null
                  facebook: null
                  instagram: null
                  tiktok: null
                  telegram: null
                  skype: null
                  subscription_date: '2014-09-29T00:00:00.000000Z'
                  unsubscription_date: null
                  tags:
                    - socio-con-empresa
                    - forma-parte-de-colectivo
                    - cargo-en-cuenta
                    - impagos
                    - cuota-premium
                  extra_fields:
                    -
                      id_field_schema: 3114
                      id_organization: 1788
                      id_field_category: 1088
                      order: 0
                      name: 'Periodicidad de pago'
                      type: DROPDOWN-FIXED
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 3136
                      id_organization: 1788
                      id_field_category: 1088
                      order: 0
                      name: 'Nombre familiar'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 3630
                      id_organization: 1788
                      id_field_category: 1088
                      order: 0
                      name: Preferencias
                      type: DROPDOWN
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 3888
                      id_organization: 1788
                      id_field_category: null
                      order: 0
                      name: Seccions
                      type: DROPDOWN-FIXED
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4075
                      id_organization: 1788
                      id_field_category: null
                      order: 0
                      name: Cursos
                      type: DROPDOWN-MULTIPLE-FIXED
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4088
                      id_organization: 1788
                      id_field_category: null
                      order: 0
                      name: 'Àrea d''interès'
                      type: DROPDOWN-MULTIPLE-FIXED
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4305
                      id_organization: 1788
                      id_field_category: null
                      order: 0
                      name: 'Nombre de la familia (apellidos niño)'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4306
                      id_organization: 1788
                      id_field_category: null
                      order: 0
                      name: 'Justificante de pago'
                      type: FILE
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4860
                      id_organization: 1788
                      id_field_category: 1468
                      order: 0
                      name: 'Comprobant sol.licitut beca'
                      type: FILE
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4888
                      id_organization: 1788
                      id_field_category: 1468
                      order: 0
                      name: 'Fotocòpia del NIF o NIE de la persona que fa la inscripció'
                      type: FILE
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4889
                      id_organization: 1788
                      id_field_category: 1468
                      order: 0
                      name: 'Fotocòpia de la targeta sanitària (CatSalut) o mútua de l’infant'
                      type: FILE
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4890
                      id_organization: 1788
                      id_field_category: 1468
                      order: 0
                      name: 'Fotocòpia de la cartilla de vacunacions de l’infant'
                      type: FILE
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4891
                      id_organization: 1788
                      id_field_category: 1469
                      order: 0
                      name: 'Nom i cognoms Pare/ Mare/ Tutor legal'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4892
                      id_organization: 1788
                      id_field_category: 1469
                      order: 0
                      name: 'NIF o NIE Pare/ Mare/ Tutor legal'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4893
                      id_organization: 1788
                      id_field_category: 1470
                      order: 0
                      name: 'Nom autoritzat 1'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4894
                      id_organization: 1788
                      id_field_category: 1470
                      order: 0
                      name: 'DNI autoritzat 1'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4895
                      id_organization: 1788
                      id_field_category: 1470
                      order: 0
                      name: 'Nom autoritzat 2'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4896
                      id_organization: 1788
                      id_field_category: 1470
                      order: 0
                      name: 'DNI autoritzat 2'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4897
                      id_organization: 1788
                      id_field_category: 1470
                      order: 0
                      name: 'Nom autoritzat 3'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4898
                      id_organization: 1788
                      id_field_category: 1470
                      order: 0
                      name: 'DNI autoritzat 3'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4899
                      id_organization: 1788
                      id_field_category: 1199
                      order: 0
                      name: 'Autorització subministrament de Paracetamol'
                      type: BOOLEAN
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4900
                      id_organization: 1788
                      id_field_category: 1471
                      order: 0
                      name: 'Indiqueu si pateix algun tipus d’alteració física o psíquica'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4901
                      id_organization: 1788
                      id_field_category: 1471
                      order: 0
                      name: 'Indiqueu si pateix alguna malaltia crònica'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4902
                      id_organization: 1788
                      id_field_category: 1471
                      order: 0
                      name: 'Indiqueu si pren algun medicament de forma periòdica'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4903
                      id_organization: 1788
                      id_field_category: 1471
                      order: 0
                      name: 'Indiqueu si pateix algun tipus d’al·lèrgia'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4904
                      id_organization: 1788
                      id_field_category: 1471
                      order: 0
                      name: 'Indiqueu qualsevol observació rellevant sobre l’alimentació'
                      type: VARCHAR
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4906
                      id_organization: 1788
                      id_field_category: 1088
                      order: 0
                      name: 'Tipo de socio'
                      type: DROPDOWN
                      visible: true
                      sort: true
                      translations: null
                      data: null
                    -
                      id_field_schema: 4907
                      id_organization: 1788
                      id_field_category: 1088
                      order: 0
                      name: 'Indica la cantidad si quieres hacer una aportación extra (€)'
                      type: NUMBER
                      visible: true
                      sort: true
                      translations: null
                      data: null
                  media: []
                  shared_media:
                    -
                      id: 60934
                      id_organization: 1788
                      model_type: App\Organization
                      model_id: 1788
                      collection_name: documents
                      name: 'Berrly - Asociaciones y Federaciones'
                      file_name: 9g9j67WX-Berrly---Asociaciones-y-Federaciones.pdf
                      mime_type: application/pdf
                      disk: gcs
                      size: 2565993
                      manipulations: []
                      custom_properties:
                        tags:
                          - proyecto-a
                        member_tags:
                          - socio-con-empresa
                      responsive_images: []
                      order_column: 56372
                      created_at: '2023-01-05T11:20:19.000000Z'
                      updated_at: '2023-01-05T11:20:19.000000Z'
                      url: 'https://storage.googleapis.com/berrly-saas/bnonprofit/documents/9g9j67WX-Berrly---Asociaciones-y-Federaciones.pdf'
                    -
                      id: 65358
                      id_organization: 1788
                      model_type: App\Organization
                      model_id: 1788
                      collection_name: documents
                      name: 'Berrly - Clubs esportius - CA'
                      file_name: jXfu5vZ3-Berrly---Clubs-esportius---CA.pdf
                      mime_type: application/pdf
                      disk: gcs
                      size: 7123622
                      manipulations: []
                      custom_properties:
                        tags:
                          - proyecto-a
                        member_tags:
                          - socio-con-empresa
                      responsive_images: []
                      order_column: 60290
                      created_at: '2023-01-31T16:02:01.000000Z'
                      updated_at: '2023-01-31T16:02:01.000000Z'
                      url: 'https://storage.googleapis.com/berrly-saas/bnonprofit/documents/jXfu5vZ3-Berrly---Clubs-esportius---CA.pdf'
                  tokens:
                    -
                      id_token: 385022
                      id_member: 532223
                      id_card_design: null
                      token: sH3jXj66hTPI0UJ4V1hv8hHv
                      type: MEMBERZONE
                      enabled: true
                      created_at: '2023-02-23T12:45:37.000000Z'
                      updated_at: null
                      expire_at: null
                      deleted_at: null
                    -
                      id_token: 457473
                      id_member: 532223
                      id_card_design: 520
                      token: OZFLTgOB4JMcYPlwvA4vfWWK
                      type: MEMBERCARD
                      enabled: true
                      created_at: '2023-06-09T08:18:34.000000Z'
                      updated_at: '2023-06-09T08:18:34.000000Z'
                      expire_at: null
                      deleted_at: null
                properties:
                  id_member:
                    type: integer
                    example: 532223
                  id_member_update:
                    type: string
                    example: null
                  type:
                    type: string
                    example: MEMBER
                  entity_type:
                    type: string
                    example: INDIVIDUAL
                  num_member:
                    type: integer
                    example: 34
                  national_id_number:
                    type: string
                    example: 40761663M
                  national_id_type:
                    type: string
                    example: DNI
                  name:
                    type: string
                    example: Abril
                  last_name:
                    type: string
                    example: 'Terrazas Alanis'
                  fname:
                    type: string
                    example: ''
                  alias:
                    type: string
                    example: ''
                  gender:
                    type: string
                    example: null
                  birthdate:
                    type: string
                    example: null
                  email:
                    type: string
                    example: abril.terrazas@example.com
                  email2:
                    type: string
                    example: null
                  email3:
                    type: string
                    example: null
                  phone_mobile:
                    type: string
                    example: '918 487907'
                  phone_number:
                    type: string
                    example: '+34 960-86-2237'
                  phone_emergency:
                    type: string
                    example: '+34 913-356606'
                  address:
                    type: string
                    example: 'Paseo Victoria, 047, 85º A'
                  postal_code:
                    type: string
                    example: '87543'
                  city:
                    type: string
                    example: 'As Botello'
                  province:
                    type: string
                    example: Sevilla
                  region:
                    type: string
                    example: 'Comunidad de Madrid'
                  country:
                    type: string
                    example: ''
                  photo:
                    type: string
                    example: 'https://storage.googleapis.com/berrly-saas/bnonprofit/members/NcCbZ3oIaF-532223.jpg'
                  legal_name:
                    type: string
                    example: null
                  industry:
                    type: string
                    example: null
                  contact_name:
                    type: string
                    example: null
                  contact_email:
                    type: string
                    example: null
                  contact_phone:
                    type: string
                    example: null
                  contact_position:
                    type: string
                    example: null
                  web:
                    type: string
                    example: null
                  linkedin:
                    type: string
                    example: null
                  twitter:
                    type: string
                    example: null
                  facebook:
                    type: string
                    example: null
                  instagram:
                    type: string
                    example: null
                  tiktok:
                    type: string
                    example: null
                  telegram:
                    type: string
                    example: null
                  skype:
                    type: string
                    example: null
                  subscription_date:
                    type: string
                    example: '2014-09-29T00:00:00.000000Z'
                  unsubscription_date:
                    type: string
                    example: null
                  tags:
                    type: array
                    example:
                      - socio-con-empresa
                      - forma-parte-de-colectivo
                      - cargo-en-cuenta
                      - impagos
                      - cuota-premium
                    items:
                      type: string
                  extra_fields:
                    type: array
                    example:
                      -
                        id_field_schema: 3114
                        id_organization: 1788
                        id_field_category: 1088
                        order: 0
                        name: 'Periodicidad de pago'
                        type: DROPDOWN-FIXED
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 3136
                        id_organization: 1788
                        id_field_category: 1088
                        order: 0
                        name: 'Nombre familiar'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 3630
                        id_organization: 1788
                        id_field_category: 1088
                        order: 0
                        name: Preferencias
                        type: DROPDOWN
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 3888
                        id_organization: 1788
                        id_field_category: null
                        order: 0
                        name: Seccions
                        type: DROPDOWN-FIXED
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4075
                        id_organization: 1788
                        id_field_category: null
                        order: 0
                        name: Cursos
                        type: DROPDOWN-MULTIPLE-FIXED
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4088
                        id_organization: 1788
                        id_field_category: null
                        order: 0
                        name: 'Àrea d''interès'
                        type: DROPDOWN-MULTIPLE-FIXED
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4305
                        id_organization: 1788
                        id_field_category: null
                        order: 0
                        name: 'Nombre de la familia (apellidos niño)'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4306
                        id_organization: 1788
                        id_field_category: null
                        order: 0
                        name: 'Justificante de pago'
                        type: FILE
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4860
                        id_organization: 1788
                        id_field_category: 1468
                        order: 0
                        name: 'Comprobant sol.licitut beca'
                        type: FILE
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4888
                        id_organization: 1788
                        id_field_category: 1468
                        order: 0
                        name: 'Fotocòpia del NIF o NIE de la persona que fa la inscripció'
                        type: FILE
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4889
                        id_organization: 1788
                        id_field_category: 1468
                        order: 0
                        name: 'Fotocòpia de la targeta sanitària (CatSalut) o mútua de l’infant'
                        type: FILE
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4890
                        id_organization: 1788
                        id_field_category: 1468
                        order: 0
                        name: 'Fotocòpia de la cartilla de vacunacions de l’infant'
                        type: FILE
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4891
                        id_organization: 1788
                        id_field_category: 1469
                        order: 0
                        name: 'Nom i cognoms Pare/ Mare/ Tutor legal'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4892
                        id_organization: 1788
                        id_field_category: 1469
                        order: 0
                        name: 'NIF o NIE Pare/ Mare/ Tutor legal'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4893
                        id_organization: 1788
                        id_field_category: 1470
                        order: 0
                        name: 'Nom autoritzat 1'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4894
                        id_organization: 1788
                        id_field_category: 1470
                        order: 0
                        name: 'DNI autoritzat 1'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4895
                        id_organization: 1788
                        id_field_category: 1470
                        order: 0
                        name: 'Nom autoritzat 2'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4896
                        id_organization: 1788
                        id_field_category: 1470
                        order: 0
                        name: 'DNI autoritzat 2'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4897
                        id_organization: 1788
                        id_field_category: 1470
                        order: 0
                        name: 'Nom autoritzat 3'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4898
                        id_organization: 1788
                        id_field_category: 1470
                        order: 0
                        name: 'DNI autoritzat 3'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4899
                        id_organization: 1788
                        id_field_category: 1199
                        order: 0
                        name: 'Autorització subministrament de Paracetamol'
                        type: BOOLEAN
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4900
                        id_organization: 1788
                        id_field_category: 1471
                        order: 0
                        name: 'Indiqueu si pateix algun tipus d’alteració física o psíquica'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4901
                        id_organization: 1788
                        id_field_category: 1471
                        order: 0
                        name: 'Indiqueu si pateix alguna malaltia crònica'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4902
                        id_organization: 1788
                        id_field_category: 1471
                        order: 0
                        name: 'Indiqueu si pren algun medicament de forma periòdica'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4903
                        id_organization: 1788
                        id_field_category: 1471
                        order: 0
                        name: 'Indiqueu si pateix algun tipus d’al·lèrgia'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4904
                        id_organization: 1788
                        id_field_category: 1471
                        order: 0
                        name: 'Indiqueu qualsevol observació rellevant sobre l’alimentació'
                        type: VARCHAR
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4906
                        id_organization: 1788
                        id_field_category: 1088
                        order: 0
                        name: 'Tipo de socio'
                        type: DROPDOWN
                        visible: true
                        sort: true
                        translations: null
                        data: null
                      -
                        id_field_schema: 4907
                        id_organization: 1788
                        id_field_category: 1088
                        order: 0
                        name: 'Indica la cantidad si quieres hacer una aportación extra (€)'
                        type: NUMBER
                        visible: true
                        sort: true
                        translations: null
                        data: null
                    items:
                      type: object
                      properties:
                        id_field_schema:
                          type: integer
                          example: 3114
                        id_organization:
                          type: integer
                          example: 1788
                        id_field_category:
                          type: integer
                          example: 1088
                        order:
                          type: integer
                          example: 0
                        name:
                          type: string
                          example: 'Periodicidad de pago'
                        type:
                          type: string
                          example: DROPDOWN-FIXED
                        visible:
                          type: boolean
                          example: true
                        sort:
                          type: boolean
                          example: true
                        translations:
                          type: string
                          example: null
                        data:
                          type: string
                          example: null
                  media:
                    type: array
                    example: []
                  shared_media:
                    type: array
                    example:
                      -
                        id: 60934
                        id_organization: 1788
                        model_type: App\Organization
                        model_id: 1788
                        collection_name: documents
                        name: 'Berrly - Asociaciones y Federaciones'
                        file_name: 9g9j67WX-Berrly---Asociaciones-y-Federaciones.pdf
                        mime_type: application/pdf
                        disk: gcs
                        size: 2565993
                        manipulations: []
                        custom_properties:
                          tags:
                            - proyecto-a
                          member_tags:
                            - socio-con-empresa
                        responsive_images: []
                        order_column: 56372
                        created_at: '2023-01-05T11:20:19.000000Z'
                        updated_at: '2023-01-05T11:20:19.000000Z'
                        url: 'https://storage.googleapis.com/berrly-saas/bnonprofit/documents/9g9j67WX-Berrly---Asociaciones-y-Federaciones.pdf'
                      -
                        id: 65358
                        id_organization: 1788
                        model_type: App\Organization
                        model_id: 1788
                        collection_name: documents
                        name: 'Berrly - Clubs esportius - CA'
                        file_name: jXfu5vZ3-Berrly---Clubs-esportius---CA.pdf
                        mime_type: application/pdf
                        disk: gcs
                        size: 7123622
                        manipulations: []
                        custom_properties:
                          tags:
                            - proyecto-a
                          member_tags:
                            - socio-con-empresa
                        responsive_images: []
                        order_column: 60290
                        created_at: '2023-01-31T16:02:01.000000Z'
                        updated_at: '2023-01-31T16:02:01.000000Z'
                        url: 'https://storage.googleapis.com/berrly-saas/bnonprofit/documents/jXfu5vZ3-Berrly---Clubs-esportius---CA.pdf'
                    items:
                      type: object
                      properties:
                        id:
                          type: integer
                          example: 60934
                        id_organization:
                          type: integer
                          example: 1788
                        model_type:
                          type: string
                          example: App\Organization
                        model_id:
                          type: integer
                          example: 1788
                        collection_name:
                          type: string
                          example: documents
                        name:
                          type: string
                          example: 'Berrly - Asociaciones y Federaciones'
                        file_name:
                          type: string
                          example: 9g9j67WX-Berrly---Asociaciones-y-Federaciones.pdf
                        mime_type:
                          type: string
                          example: application/pdf
                        disk:
                          type: string
                          example: gcs
                        size:
                          type: integer
                          example: 2565993
                        manipulations:
                          type: array
                          example: []
                        custom_properties:
                          type: object
                          properties:
                            tags:
                              type: array
                              example:
                                - proyecto-a
                              items:
                                type: string
                            member_tags:
                              type: array
                              example:
                                - socio-con-empresa
                              items:
                                type: string
                        responsive_images:
                          type: array
                          example: []
                        order_column:
                          type: integer
                          example: 56372
                        created_at:
                          type: string
                          example: '2023-01-05T11:20:19.000000Z'
                        updated_at:
                          type: string
                          example: '2023-01-05T11:20:19.000000Z'
                        url:
                          type: string
                          example: 'https://storage.googleapis.com/berrly-saas/bnonprofit/documents/9g9j67WX-Berrly---Asociaciones-y-Federaciones.pdf'
                  tokens:
                    type: array
                    example:
                      -
                        id_token: 385022
                        id_member: 532223
                        id_card_design: null
                        token: sH3jXj66hTPI0UJ4V1hv8hHv
                        type: MEMBERZONE
                        enabled: true
                        created_at: '2023-02-23T12:45:37.000000Z'
                        updated_at: null
                        expire_at: null
                        deleted_at: null
                      -
                        id_token: 457473
                        id_member: 532223
                        id_card_design: 520
                        token: OZFLTgOB4JMcYPlwvA4vfWWK
                        type: MEMBERCARD
                        enabled: true
                        created_at: '2023-06-09T08:18:34.000000Z'
                        updated_at: '2023-06-09T08:18:34.000000Z'
                        expire_at: null
                        deleted_at: null
                    items:
                      type: object
                      properties:
                        id_token:
                          type: integer
                          example: 385022
                        id_member:
                          type: integer
                          example: 532223
                        id_card_design:
                          type: string
                          example: null
                        token:
                          type: string
                          example: sH3jXj66hTPI0UJ4V1hv8hHv
                        type:
                          type: string
                          example: MEMBERZONE
                        enabled:
                          type: boolean
                          example: true
                        created_at:
                          type: string
                          example: '2023-02-23T12:45:37.000000Z'
                        updated_at:
                          type: string
                          example: null
                        expire_at:
                          type: string
                          example: null
                        deleted_at:
                          type: string
                          example: null
      tags:
        - Members
      requestBody:
        required: false
        content:
          application/json:
            schema:
              type: object
              properties:
                national_id_number:
                  type: string
                  description: 'National ID number value.'
                  example: 40761663M
                national_id_type:
                  type: string
                  description: 'National ID type value: CIF, DNI, NIE, PASSPORT, OTHER.'
                  example: DNI
                num_member:
                  type: integer
                  description: 'Num Member value.'
                  example: 342
                name:
                  type: string
                  description: 'Name value.'
                  example: Abril
                last_name:
                  type: string
                  description: 'Last name value.'
                  example: 'Terrazas Alanis'
                alias:
                  type: string
                  description: 'Alias value.'
                  example: Cerral
                gender:
                  type: string
                  description: 'MALE, FEMALE, "Any option you can write" value.'
                  example: FEMALE
                birthdate:
                  type: string
                  description: 'Birthdate value.'
                  example: '1983-06-24'
                email:
                  type: string
                  description: 'Email value.'
                  example: abrilterrazas@example.com
                email2:
                  type: string
                  description: 'Email value.'
                  example: abrilterrazas2@example.com
                email3:
                  type: string
                  description: 'Email value.'
                  example: terrazi83@example.com
                phone_mobile:
                  type: string
                  description: 'Phone mobile value.'
                  example: '+34666000000'
                phone_number:
                  type: string
                  description: 'Phone number value.'
                  example: '+34933456789'
                phone_emergency:
                  type: string
                  description: 'Phone emergency number value.'
                  example: '+34933456789'
                address:
                  type: string
                  description: 'Address value.'
                  example: 'Paseo Victoria, 047, 85º A'
                postal_code:
                  type: string
                  description: 'Postal code value.'
                  example: '87543'
                city:
                  type: string
                  description: 'City value.'
                  example: Sevilla
                province:
                  type: string
                  description: 'Province value.'
                  example: Sevilla
                region:
                  type: string
                  description: 'Region value.'
                  example: Andalucia
                country:
                  type: string
                  description: 'Country value.'
                  example: Spain
                comments:
                  type: string
                  description: 'Comments value.'
                  example: null
                legal_name:
                  type: string
                  description: 'Legal name value.'
                  example: null
                industry:
                  type: string
                  description: 'Industry value.'
                  example: null
                contact_name:
                  type: string.
                  description: ''
                  example: null
                contact_email:
                  type: string.
                  description: ''
                  example: null
                contact_phone:
                  type: string.
                  description: ''
                  example: null
                contact_position:
                  type: string.
                  description: ''
                  example: null
                web:
                  type: string.
                  description: ''
                  example: null
                linkedin:
                  type: string.
                  description: ''
                  example: null
                facebook:
                  type: string.
                  description: ''
                  example: null
                instagram:
                  type: string.
                  description: ''
                  example: null
                tiktok:
                  type: string.
                  description: ''
                  example: null
                telegram:
                  type: string.
                  description: ''
                  example: null
                skype:
                  type: string.
                  description: ''
                  example: null
                iban:
                  type: string.
                  description: ''
                  example: null
                payment_method:
                  type: string.
                  description: ''
                  example: null
                iban_name:
                  type: string.
                  description: ''
                  example: null
                bic:
                  type: string.
                  description: ''
                  example: null
                membership_fee:
                  type: string.
                  description: ''
                  example: null
                subscription_date:
                  type: string.
                  description: 'Date when member was first subscribed to organization.'
                  example: '2003-09-24'
    get:
      summary: List
      operationId: list
      description: 'List all members based on the given request parameters.'
      parameters:
        -
          in: query
          name: tag
          description: 'You can filter only members with this tag'
          example: voluptatibus
          required: false
          schema:
            type: string
            description: 'You can filter only members with this tag'
            example: voluptatibus
        -
          in: query
          name: excluded_tag
          description: 'You can filter to exclude only members with this tag'
          example: repudiandae
          required: false
          schema:
            type: string
            description: 'You can filter to exclude only members with this tag'
            example: repudiandae
        -
          in: query
          name: id_extra_field
          description: 'You can filter only members with this Extra Field'
          example: 20
          required: false
          schema:
            type: integer
            description: 'You can filter only members with this Extra Field'
            example: 20
        -
          in: query
          name: value_extra_field
          description: 'If you want to filter by Extra Field you must set a "value"'
          example: voluptatem
          required: false
          schema:
            type: string
            description: 'If you want to filter by Extra Field you must set a "value"'
            example: voluptatem
        -
          in: query
          name: subset
          description: 'SUBSCRIBED , UNSUBSCRIBED or ALL.'
          example: ALL
          required: false
          schema:
            type: string
            description: 'SUBSCRIBED , UNSUBSCRIBED or ALL.'
            example: ALL
        -
          in: query
          name: type
          description: 'UNSUBSCRIBED_NO_DATA, UNSUBSCRIBED, PREVIEW, UPDATE or MEMBER.'
          example: MEMBER
          required: false
          schema:
            type: string
            description: 'UNSUBSCRIBED_NO_DATA, UNSUBSCRIBED, PREVIEW, UPDATE or MEMBER.'
            example: MEMBER
      responses:
        403:
          description: ''
          content:
            application/json:
              schema:
                type: object
                example:
                  error: 'Forbidden. Invalid Token.'
                properties:
                  error:
                    type: string
                    example: 'Forbidden. Invalid Token.'
      tags:
        - Members
  /v1/members/search:
    post:
      summary: Search
      operationId: search
      description: 'Searches for members based on the given request parameters.'
      parameters: []
      responses: {  }
      tags:
        - Members
      requestBody:
        required: false
        content:
          application/json:
            schema:
              type: object
              properties:
                tag:
                  type: string
                  description: 'You can filter only members with this tag'
                  example: natus
                excluded_tag:
                  type: string
                  description: 'You can filter to exclude only members with this tag'
                  example: voluptates
                id_extra_field:
                  type: integer
                  description: 'You can filter only members with this Extra Field'
                  example: 15
                value_extra_field:
                  type: string
                  description: 'If you want to filter by Extra Field you must set a "value"'
                  example: vitae
  '/v1/members/set-extra-field/{id_member}/{id_field_schema}':
    post:
      summary: 'Set Extra Field'
      operationId: setExtraField
      description: 'Sets extra field for a Member in the organization.'
      parameters: []
      responses: {  }
      tags:
        - Members
      requestBody:
        required: false
        content:
          application/json:
            schema:
              type: object
              properties:
                value:
                  type: string
                  description: 'Extra field value to set: 2017-10-01, Mountain, YES, NO.'
                  example: 'YES'
    parameters:
      -
        in: path
        name: id_member
        description: 'The ID of the member to set tags for'
        example: 13
        required: true
        schema:
          type: integer
      -
        in: path
        name: id_field_schema
        description: 'The ID of the extra field'
        example: 12
        required: true
        schema:
          type: integer
  '/v1/members/set-tag/{id_member}':
    post:
      summary: 'Set Tags'
      operationId: setTags
      description: 'Sets tags for a member in the organization.'
      parameters: []
      responses: {  }
      tags:
        - Members
      requestBody:
        required: false
        content:
          application/json:
            schema:
              type: object
              properties:
                tags:
                  type: string
                  description: 'Tags to add comma separated:'
                  example: 'red,green,adult,with-a-red-hat'
    parameters:
      -
        in: path
        name: id_member
        description: 'The ID of the member to set tags for'
        example: 15
        required: true
        schema:
          type: integer
  /v1/members/last_num:
    get:
      summary: 'Get Last Num'
      operationId: getLastNum
      description: 'Retrieve last Num Member from Organization'
      parameters: []
      responses:
        403:
          description: ''
          content:
            application/json:
              schema:
                type: object
                example:
                  error: 'Forbidden. Invalid Token.'
                properties:
                  error:
                    type: string
                    example: 'Forbidden. Invalid Token.'
      tags:
        - Members
  /v1/organizations/me:
    get:
      summary: 'Get Organization'
      operationId: getOrganization
      description: 'Retrieves the current organization information & properties.'
      parameters: []
      responses:
        200:
          description: ''
          content:
            application/json:
              schema:
                type: object
                example:
                  id_organization: 1788
                  id_organization_ulid: ORG_01G5K5WVYGDA6Z28F91EVY7ET6
                  name: 'Berrly Non-profit'
                  shortname: bnonprofit
                  email: info@berrly.com
                  phone: '+34930328370'
                  address: null
                  province: null
                  city: null
                  country: Spain
                  postal_code: null
                  timezone: Europe/Madrid
                  business_name: null
                  vat_number: null
                  vat: 21
                  logo: 'https://storage.googleapis.com/berrly-saas-development/bnonprofit/FfKwAhMcqp-logo.png'
                  language: es
                  language_member_zone: ''
                  sector: null
                  updated_at: '2023-07-14T09:48:05.000000Z'
                  created_at: '2022-06-15T07:57:54.000000Z'
                properties:
                  id_organization:
                    type: integer
                    example: 1788
                  id_organization_ulid:
                    type: string
                    example: ORG_01G5K5WVYGDA6Z28F91EVY7ET6
                  name:
                    type: string
                    example: 'Berrly Non-profit'
                  shortname:
                    type: string
                    example: bnonprofit
                  email:
                    type: string
                    example: info@berrly.com
                  phone:
                    type: string
                    example: '+34930328370'
                  address:
                    type: string
                    example: null
                  province:
                    type: string
                    example: null
                  city:
                    type: string
                    example: null
                  country:
                    type: string
                    example: Spain
                  postal_code:
                    type: string
                    example: null
                  timezone:
                    type: string
                    example: Europe/Madrid
                  business_name:
                    type: string
                    example: null
                  vat_number:
                    type: string
                    example: null
                  vat:
                    type: integer
                    example: 21
                  logo:
                    type: string
                    example: 'https://storage.googleapis.com/berrly-saas-development/bnonprofit/FfKwAhMcqp-logo.png'
                  language:
                    type: string
                    example: es
                  language_member_zone:
                    type: string
                    example: ''
                  sector:
                    type: string
                    example: null
                  updated_at:
                    type: string
                    example: '2023-07-14T09:48:05.000000Z'
                  created_at:
                    type: string
                    example: '2022-06-15T07:57:54.000000Z'
      tags:
        - Organizations
  /v1/tags:
    get:
      summary: 'Get All Tags'
      operationId: getAllTags
      description: 'Retrieves all tags for the current organization.'
      parameters: []
      responses:
        403:
          description: ''
          content:
            application/json:
              schema:
                type: object
                example:
                  error: 'Forbidden. Invalid Token.'
                properties:
                  error:
                    type: string
                    example: 'Forbidden. Invalid Token.'
      tags:
        - Tags
    post:
      summary: Create
      operationId: create
      description: 'Creates a new tag.'
      parameters: []
      responses: {  }
      tags:
        - Tags
      requestBody:
        required: false
        content:
          application/json:
            schema:
              type: object
              properties:
                name:
                  type: string
                  description: 'Name of the new tag.'
                  example: with-a-red-hat
tags:
  -
    name: Events
    description: ''
  -
    name: Members
    description: ''
  -
    name: Organizations
    description: ''
  -
    name: Tags
    description: ''
components:
  securitySchemes:
    default:
      type: http
      scheme: bearer
      description: "You can retrieve your token by visiting API module, API keys section, and clicking <b>Add</b> to create new tokens.\n                        <aside class=\"notice\">\n                        <p>Berrly uses API keys to allow access to the API. You will need API module activated. If you can't see any API entrance in the main side bar you can write us an email at support@berrly.cloud.</p>\n                        <p>Berrly expects for the API key to be included in all API requests to the server in a header that looks like the following:</p>\n                        </aside>"
security:
  -
    default: []
